#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 path-io
version:              1.6.3
visibility:           public
id:                   path-io-1.6.3-7YjEqbvJNqG1IzxSGyGM1a
key:                  path-io-1.6.3-7YjEqbvJNqG1IzxSGyGM1a
license:              BSD-3-Clause
maintainer:           Mark Karpov <markkarpov92@gmail.com>
author:               Mark Karpov <markkarpov92@gmail.com>
homepage:             https://github.com/mrkkrp/path-io
synopsis:             Interface to ‘directory’ package for users of ‘path’
description:          Interface to ‘directory’ package for users of ‘path’.
category:             System, Filesystem
abi:                  dac817b0b5530dd9f6dead981398dc66
exposed:              True
exposed-modules:      Path.IO
import-dirs:          /usr/lib/ghc-8.10.5/site-local/path-io-1.6.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/path-io-1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/path-io-1.6.3
hs-libraries:         HSpath-io-1.6.3-7YjEqbvJNqG1IzxSGyGM1a
depends:
    base-4.14.2.0 containers-0.6.4.1 directory-1.3.6.0
    dlist-1.0-2pxhAw6JY91eMk6tw7lC2 exceptions-0.10.4 filepath-1.4.2.1
    path-0.8.0-Jmb502JJEg14OSfruVAV7G
    temporary-1.3-8GcUVXeVeMb6fVcXKNialU time-1.9.3
    transformers-0.5.6.2 unix-compat-0.5.3-1KqjYp6svTH6EdzCzH8QEz

haddock-interfaces:   /usr/share/doc/haskell-path-io/html/path-io.haddock
haddock-html:         /usr/share/doc/haskell-path-io/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

